==> zio-aws-iot_2.12-5.17.191.2-sources.jar: zio/aws/iot/model/CreateMitigationActionResponse.scala <==
package zio.aws.iot.model
import zio.ZIO
import zio.aws.iot.model.primitives.{MitigationActionId, MitigationActionArn}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateMitigationActionResponse(
    actionArn: Optional[MitigationActionArn] = Optional.Absent,
    actionId: Optional[MitigationActionId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot.model.CreateMitigationActionResponse = {
    import CreateMitigationActionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot.model.CreateMitigationActionResponse
      .builder()
      .optionallyWith(
        actionArn.map(value =>
          MitigationActionArn.unwrap(value): java.lang.String
        )
      )(_.actionArn)
      .optionallyWith(
        actionId.map(value =>
          MitigationActionId.unwrap(value): java.lang.String
        )
      )(_.actionId)
      .build()
  }
  def asReadOnly: zio.aws.iot.model.CreateMitigationActionResponse.ReadOnly =
    zio.aws.iot.model.CreateMitigationActionResponse.wrap(buildAwsValue())
}
object CreateMitigationActionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot.model.CreateMitigationActionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot.model.CreateMitigationActionResponse =
      zio.aws.iot.model.CreateMitigationActionResponse(
        actionArn.map(value => value),
        actionId.map(value => value)
      )
    def actionArn: Optional[MitigationActionArn]
    def actionId: Optional[MitigationActionId]
    def getActionArn: ZIO[Any, AwsError, MitigationActionArn] =
      AwsError.unwrapOptionField("actionArn", actionArn)
    def getActionId: ZIO[Any, AwsError, MitigationActionId] =
      AwsError.unwrapOptionField("actionId", actionId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot.model.CreateMitigationActionResponse
  ) extends zio.aws.iot.model.CreateMitigationActionResponse.ReadOnly {
    override val actionArn: Optional[MitigationActionArn] =
      zio.aws.core.internal
        .optionalFromNullable(impl.actionArn())
        .map(value => zio.aws.iot.model.primitives.MitigationActionArn(value))
    override val actionId: Optional[MitigationActionId] = zio.aws.core.internal
      .optionalFromNullable(impl.actionId())
      .map(value => zio.aws.iot.model.primitives.MitigationActionId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot.model.CreateMitigationActionResponse
  ): zio.aws.iot.model.CreateMitigationActionResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-iot_3-5.17.148.1-sources.jar: zio/aws/iot/model/CreateMitigationActionResponse.scala <==
package zio.aws.iot.model
import zio.ZIO
import zio.aws.iot.model.primitives.{MitigationActionId, MitigationActionArn}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class CreateMitigationActionResponse(
    actionArn: Option[MitigationActionArn] = None,
    actionId: Option[MitigationActionId] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot.model.CreateMitigationActionResponse = {
    import CreateMitigationActionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot.model.CreateMitigationActionResponse
      .builder()
      .optionallyWith(
        actionArn.map(value =>
          MitigationActionArn.unwrap(value): java.lang.String
        )
      )(_.actionArn)
      .optionallyWith(
        actionId.map(value =>
          MitigationActionId.unwrap(value): java.lang.String
        )
      )(_.actionId)
      .build()
  }
  def asReadOnly: zio.aws.iot.model.CreateMitigationActionResponse.ReadOnly =
    zio.aws.iot.model.CreateMitigationActionResponse.wrap(buildAwsValue())
}
object CreateMitigationActionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot.model.CreateMitigationActionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot.model.CreateMitigationActionResponse =
      zio.aws.iot.model.CreateMitigationActionResponse(
        actionArn.map(value => value),
        actionId.map(value => value)
      )
    def actionArn: Option[MitigationActionArn]
    def actionId: Option[MitigationActionId]
    def getActionArn: ZIO[Any, AwsError, MitigationActionArn] =
      AwsError.unwrapOptionField("actionArn", actionArn)
    def getActionId: ZIO[Any, AwsError, MitigationActionId] =
      AwsError.unwrapOptionField("actionId", actionId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot.model.CreateMitigationActionResponse
  ) extends zio.aws.iot.model.CreateMitigationActionResponse.ReadOnly {
    override val actionArn: Option[MitigationActionArn] = scala
      .Option(impl.actionArn())
      .map(value => zio.aws.iot.model.primitives.MitigationActionArn(value))
    override val actionId: Option[MitigationActionId] = scala
      .Option(impl.actionId())
      .map(value => zio.aws.iot.model.primitives.MitigationActionId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot.model.CreateMitigationActionResponse
  ): zio.aws.iot.model.CreateMitigationActionResponse.ReadOnly = new Wrapper(
    impl
  )
}
